<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Επεξεργασία Φόρμα Παραλήπτες");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Επεξεργασία Φόρμα Παραλήπτες");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "φόρμα Σελίδα");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Μπορείτε να ρυθμίσετε περισσότερους από έναν παραλήπτη διαχωρίζοντας τα μηνύματα ηλεκτρονικού ταχυδρομείου με κόμμα.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Αποθήκευση παραλήπτη ...");
define('VIEW_FORM_TABLES_HEADING', "Προβολή πινάκων φόρμας");
define('VIEW_FORM_TABLES_BTN', "Προβολή πινάκων φόρμας");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Επιλέξτε έναν πίνακα για προβολή");
define('VIEW_FORM_TABLES_FILTER_READ', "Φιλτράρετε τα μηνύματα");
?>